@@ -4,8 +4,7 @@ use std::sync::Arc;
 
 pub fn handle_watched_files(_session: Arc<Session>, events: Vec<FileEvent>) {
     for _event in events {
-        // FileChangeType::DELETED wants fully-qualified type, but that doesn't work
-        todo!();
+        // TODO FileChangeType::DELETED wants fully-qualified type, but that doesn't work
         // if let FileChangeType::DELETED {} = event.typ {
         //     let _ = session.remove_document(&event.uri);
         // }
